@@ -1,5 +1,8 @@
 from .aio import AIOFile
-from .utils import LineReader, Reader, Writer
+from .utils import (
+    BinaryFileWrapper, FileIOWrapperBase, LineReader, Reader, TextFileWrapper,
+    Writer, async_open,
+)
 from .version import (
     __author__, __version__, author_info, package_info, package_license,
     project_home, team_email, version_info,
@@ -7,16 +10,20 @@ from .version import (
 
 
 __all__ = (
+    "AIOFile",
+    "BinaryFileWrapper",
+    "FileIOWrapperBase",
+    "LineReader",
+    "Reader",
+    "TextFileWrapper",
+    "Writer",
     "__author__",
     "__version__",
+    "async_open",
     "author_info",
     "package_info",
-    "AIOFile",
-    "LineReader",
     "package_license",
     "project_home",
-    "Reader",
     "team_email",
     "version_info",
-    "Writer",
 )
