@@ -124,29 +124,30 @@ class LineReader(collections.abc.AsyncIterable):
 
     async def readline(self) -> Union[str, bytes]:
         while True:
-            chunk = await self.__reader.read_chunk()
-
-            if chunk:
-                if self.linesep not in chunk:   # type: ignore
-                    self._buffer.write(chunk)
-                    continue
-
-                self._buffer.write(chunk)
-
-            self._buffer.seek(0)
             line = self._buffer.readline()
-            tail = self._buffer.read()
+            if line and line.endswith(self.linesep):
+                return line
 
-            self._buffer.seek(0)
+            buffer_remainder = line + self._buffer.read()
             self._buffer.truncate(0)
-            self._buffer.write(tail)
+            self._buffer.seek(0)
 
-            return line
+            # No line in buffer, read more data
+            chunk = await self.__reader.read_chunk()
+            if not chunk:
+                # No more data to read, return any remaining content in the buffer
+                return buffer_remainder
+            # We have more data to read, write it to the buffer and handle it in the next iteration
+            self._buffer.write(buffer_remainder)
+            self._buffer.write(chunk)
+            self._buffer.seek(0)
 
     async def __anext__(self) -> Union[bytes, str]:
         line = await self.readline()
 
         if not line:
+            # We are finished, close the buffer and raise StopAsyncIteration
+            self._buffer.close()
             raise StopAsyncIteration(line)
 
         return line
@@ -189,6 +190,12 @@ class FileIOWrapperBase(ABC):
     def tell(self) -> int:
         return self._offset
 
+    async def flush(self, sync_metadata: bool = False) -> None:
+        if sync_metadata:
+            await self.file.fsync()
+        else:
+            await self.file.fdsync()
+
     async def close(self) -> None:
         await self.file.close()
 
@@ -207,7 +214,7 @@ class FileIOWrapperBase(ABC):
         return LineReader(self.file)
 
     def iter_chunked(self, chunk_size: int = Reader.CHUNK_SIZE) -> Reader:
-        return Reader(self.file, chunk_size=chunk_size)
+        return Reader(self.file, chunk_size=chunk_size, offset=self._offset)
 
 
 class BinaryFileWrapper(FileIOWrapperBase):
@@ -328,7 +335,7 @@ class TextFileWrapper(FileIOWrapperBase):
 
 def async_open(
     file_specifier: Union[str, Path, FileIOType],
-    mode: str = "r", *args: Any, **kwargs: Any
+    mode: str = "r", *args: Any, **kwargs: Any,
 ) -> Union[BinaryFileWrapper, TextFileWrapper]:
     if isinstance(file_specifier, (str, Path)):
         afp = AIOFile(str(file_specifier), mode, *args, **kwargs)
